> Array#each, Array#map, and Array#select have been rewritten in Ruby.
> A microbenchmark made on Array#each, for instance, shows it is 7x faster.
This is awesome. I can’t wait to see further improvements as they continue to optimize for the JIT.
> A microbenchmark made on Array#each, for instance, shows it is 7x faster.
This is awesome. I can’t wait to see further improvements as they continue to optimize for the JIT.
No comments yet.